/**
 *
 */
package org.vcs.bazaar.eclipse.ui.preferences;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.eclipse.ui.dialogs.PreferenceLinkArea;
import org.eclipse.ui.preferences.IWorkbenchPreferenceContainer;
import org.vcs.bazaar.eclipse.ui.EclipseBazaarUI;
import org.vcs.bazaar.eclipse.ui.UITexts;
import org.vcs.bazaar.eclipse.ui.decorator.BazaarLightweightDecorator;
/**
 *
 * @author Guillermo Gonzalez <guillo.gonzo AT gmail DOT com>
 *
 */
public class BazaarDecoratorPreferencePage extends FieldEditorPreferencePage implements IWorkbenchPreferencePage {

	private BooleanFieldEditor projectTextDecoratorEnabled;
	private BooleanFieldEditor fileTextDecoratorEnabled;
	private BooleanFieldEditor statusTextDecoratorEnabled;
	private BooleanFieldEditor statusOverlayDecoratorEnabled;

	public BazaarDecoratorPreferencePage() {
		super(GRID);
		setPreferenceStore(EclipseBazaarUI.getDefault().getPreferenceStore());
	}

	public void init(IWorkbench workbench) {
	}

	@Override
	protected void createFieldEditors() {
		new PreferenceLinkArea(getFieldEditorParent(), SWT.NONE,
				"org.eclipse.ui.preferencePages.Decorators",
				UITexts.BazaarDecoratorPreferencesPage_labelDecorationsLink, (IWorkbenchPreferenceContainer) getContainer(), null);
		new PreferenceLinkArea(getFieldEditorParent(), SWT.NONE,
				"org.eclipse.ui.preferencePages.ColorsAndFonts",
				UITexts.BazaarDecoratorPreferencesPage_colorsAndFontsLink, (IWorkbenchPreferenceContainer) getContainer(), null);
		
		fileTextDecoratorEnabled = new BooleanFieldEditor(BazaarPreferenceConstants.FILE_TEXT_DECORATOR, UITexts.BazaarDecoratorPreferencesPage_enable_file_text_decorator,
				getFieldEditorParent());
		addField(fileTextDecoratorEnabled);
		projectTextDecoratorEnabled = new BooleanFieldEditor(BazaarPreferenceConstants.PROJECT_TEXT_DECORATOR, UITexts.BazaarDecoratorPreferencesPage_enable_project_text_decorator,
				getFieldEditorParent());
		addField(projectTextDecoratorEnabled);
		statusTextDecoratorEnabled = new BooleanFieldEditor(BazaarPreferenceConstants.STATUS_TEXT_DECORATOR, UITexts.BazaarDecoratorPreferencesPage_enable_status_text_decorator,
				getFieldEditorParent());
		addField(statusTextDecoratorEnabled);
		statusOverlayDecoratorEnabled = new BooleanFieldEditor(BazaarPreferenceConstants.STATUS_OVERLAY_DECORATOR, UITexts.BazaarDecoratorPreferencesPage_enable_status_overlay_decorator,
				getFieldEditorParent());
		addField(statusOverlayDecoratorEnabled);
	}

	@Override
    protected void performDefaults() {
		super.performDefaults();
		applyDecoratorPreferences();
	}

    @Override
    public boolean performOk() {
		super.performOk();
		applyDecoratorPreferences();
		BazaarLightweightDecorator.refresh();
		return true;
	}

	private void applyDecoratorPreferences() {
		try {
			if(statusOverlayDecoratorEnabled.getBooleanValue() || statusTextDecoratorEnabled.getBooleanValue()) {
				EclipseBazaarUI.getDefault().getWorkbench().getDecoratorManager().setEnabled(BazaarLightweightDecorator.class.getName(), true);
			} else {
				EclipseBazaarUI.getDefault().getWorkbench().getDecoratorManager().setEnabled(BazaarLightweightDecorator.class.getName(), false);
			}
		} catch(CoreException e) {
			EclipseBazaarUI.log(e);
		}
	}

}
